==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebFilteringStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringStrategyDescription } from "./WebFilteringStrategyDescription";
/**
 * @hidden
 */
export let WebFilteringStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringStrategyDescriptionMetadata.a == null) {
                WebFilteringStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringStrategyDescriptionMetadata.c(WebFilteringStrategyDescriptionMetadata.a);
            }
            if (a.j(WebFilteringStrategyDescriptionMetadata.a)) {
                return;
            }
            a.y(WebFilteringStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebFilteringStrategyDescriptionMetadata.b(a);
            a.aa("WebFilteringStrategy", () => new WebFilteringStrategyDescription());
            a.z("WebFilteringStrategy", WebFilteringStrategyDescriptionMetadata.a);
        }
    }
    WebFilteringStrategyDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringStrategyDescriptionMetadata, 'WebFilteringStrategyDescriptionMetadata');
    WebFilteringStrategyDescriptionMetadata.a = null;
    return WebFilteringStrategyDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFilteringStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringStrategyDescription } from "./WebFilteringStrategyDescription";
/**
 * @hidden
 */
export let WebFilteringStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringStrategyDescriptionMetadata.a == null) {
                WebFilteringStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringStrategyDescriptionMetadata.c(WebFilteringStrategyDescriptionMetadata.a);
            }
            if (a.k(WebFilteringStrategyDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFilteringStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebFilteringStrategyDescriptionMetadata.b(a);
            a.ac("WebFilteringStrategy", () => new WebFilteringStrategyDescription());
            a.ab("WebFilteringStrategy", WebFilteringStrategyDescriptionMetadata.a);
        }
    }
    WebFilteringStrategyDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFilteringStrategyDescriptionMetadata, 'WebFilteringStrategyDescriptionMetadata');
    WebFilteringStrategyDescriptionMetadata.a = null;
    return WebFilteringStrategyDescriptionMetadata;
})();
